import os

# API Endpoints
KORBIT_HOST = os.getenv("KORBIT_HOST", "https://mentor.korbit.ai:8000")
KORBIT_SCAN_REPORT_URL = f"{KORBIT_HOST}/database/v3/scans"
KORBIT_CODE_ANALYSIS_SERVICE = f"{KORBIT_HOST}/code-analysis/check"
KORBIT_CODE_ANALYSIS_CHECK = f"{KORBIT_CODE_ANALYSIS_SERVICE}/files"

# Local paths
KORBIT_LOCAL_FOLDER = ".korbit"
KORBIT_LOCAL_OUTPUT_LOG_FILE = f"{KORBIT_LOCAL_FOLDER}/scan.log"

# Exit codes
KORBIT_COMMAND_EXIT_CODE_UNKNOWN_ERROR = 90
KORBIT_COMMAND_EXIT_CODE_ISSUES_FOUND_WITHIN_THRESHOLD = 91
KORBIT_COMMAND_EXIT_CODE_CHECK_FAILED = 92
KORBIT_COMMAND_EXIT_CODE_AUTH_FAILED = 93
